@@ -7,7 +7,7 @@ use warnings;
 package Acme::ConspiracyTheory::Random;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 
 use Exporter::Shiny qw( theory bad_punctuation );
 use List::Util 1.54 ();
@@ -170,6 +170,7 @@ sub fake_animal {
 		'dragon',
 		'wyvern',
 		'yeti',
+		'Loch Ness monster',
 	);
 	
 	_MERGE_( $redstring, fake_animal => $animal );
@@ -708,7 +709,6 @@ sub biologist {  # and medics
 		'Charles Darwin',
 		'Edward Jenner',
 		'Robert Koch',
-		'Edward Jenner',
 		'Carl Linneaus',
 		'Alexander Fleming',
 	);
@@ -1194,6 +1194,8 @@ sub hidden_truth {
 						'Columbine',
 						'Sandy Hook',
 						'the Boston Marathon Bombing',
+						'Malaysia Airlines Flight 370',
+						'the JFK assassination',
 					);
 					$redstring->{topic} = { name => 'false flag operations', plural => 1 };
 					"$badevent was orchestrated by the US government";
@@ -1242,6 +1244,23 @@ sub hidden_truth {
 					$redstring->{topic} = { name => 'Nazis', plural => 1 };
 					"there is a Nazi base in Antarctica";
 				},
+				sub {
+					my $website = website( $redstring );
+					my $spies   = _RANDOM_(
+						'spies',
+						'the CIA',
+						'GCHQ',
+						'the NSA',
+						'the Kremlin',
+						'Ipsos MORI',
+						sub {
+							my $g = shady_group( $redstring );
+							$redstring->{shady_group}{plural} ? $g : "spies from $g";
+						}
+					);
+					$redstring->{topic} = { name => 'biscuits', plural => 1 };
+					"$spies are using cookies to see everything you look at on $website";
+				},
 			);
 		},
 		sub {
@@ -1252,7 +1271,7 @@ sub hidden_truth {
 				'Curious George used to have a tail',
 				'Febreze used to have another E in it',
 				'Froot Loops used to be Fruit Loops',
-				'the Monopoly man is supposed to have a monacle',
+				'the Monopoly man is supposed to have a monocle',
 				'Kitkat used to have a hyphen',
 				'the Mona Lisa used to smile more',
 				'C-3PO never used to have a silver leg',
@@ -1353,8 +1372,9 @@ sub hidden_truth {
 		sub {
 			my $chemicals = chemicals( $redstring );
 			my $animal    = real_animal( $redstring );
+			my $s         = ($animal ne 'fish') ? 's' : '';
 			my $attribute = attribute( $redstring );
-			"the $chemicals in the water is turning the $animal" . "s $attribute";
+			"the $chemicals in the water is turning the $animal$s $attribute";
 		},
 		sub {
 			my $chemicals = chemicals( $redstring );
@@ -2049,8 +2069,9 @@ sub numerology {
 sub bad_punctuation {
 	my ( $string, $cancel ) = @_;
 	unless ( $cancel ) {
-		$string =~ s/ (\w) ([,!?]) / $1 . _RANDOM_(    $2, " $2", " $2", " $2$2") /exg;
-		$string =~ s/ (\w) ([.])   / $1 . _RANDOM_($2, $2, " $2", " ", " $2$2$2") /exg;
+		$string =~ s/ ([A-Za-z]) ([,!?]) / $1 . _RANDOM_(    $2, " $2", " $2", " $2$2") /exg;
+		$string =~ s/ ([A-Za-z]) ([.])   / $1 . _RANDOM_($2, $2, " $2", " ", " $2$2$2") /exg;
+		$string =~ s/\!/_RANDOM_('!', '!', '!!',  "!!!!")/ex;
 	}
 	return $string;
 }
